@@ -1,7 +1,7 @@
 package Text::ANSI::BaseUtil;
 
-our $DATE = '2015-08-12'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-08-13'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,12 +9,8 @@ use warnings;
 
 use List::Util qw(min max);
 
-# used to find/strip escape codes from string
-our $re       = qr/
-                      #\e\[ (?: (\d+) ((?:;[^;]+?)*) )? ([\x40-\x7e])
-                      # without captures
-                      \e\[ (?: \d+ (?:;[^;]+?)* )? [\x40-\x7e]
-                  /osx;
+our $re       = qr/\e\[[0-9;]+m/s;
+our $re_mult  = qr/(?:\e\[[0-9;]+m)+/s;
 
 sub ta_detect {
     my $text = shift;
@@ -58,13 +54,13 @@ sub ta_strip {
 sub ta_extract_codes {
     my $text = shift;
     my $res = "";
-    $res .= $1 while $text =~ /((?:$re)+)/go;
+    $res .= $1 while $text =~ /($re_mult)/go;
     $res;
 }
 
 sub ta_split_codes {
     my $text = shift;
-    return split(/((?:$re)+)/o, $text);
+    return split(/($re_mult)/o, $text);
 }
 
 sub ta_split_codes_single {
@@ -92,6 +88,14 @@ sub _ta_wrap {
     # dealing with ANSI codes by splitting codes first (to easily do color
     # resets/replays), then grouping into words and paras, then doing wrapping.
 
+    my $_re1 = $is_mb ?
+        qr/($Text::WideChar::Util::re_cjk+)|(\S+)|(\s+)/ :
+        qr/()(\S+)|(\s+)/;
+
+    my $_re2 = $is_mb ?
+        qr/($Text::WideChar::Util::re_cjk_class+)|
+           ($Text::WideChar::Util::re_cjk_negclass+)/x : undef;
+
     my @termst; # store term type, 's' (spaces), 'w' (word), 'c' (cjk word) or
                 # 'p' (parabreak)
     my @terms;  # store the text (w/ codes); for ws, only store the codes
@@ -111,20 +115,23 @@ sub _ta_wrap {
 
             my @s; # (WORD1, TYPE, ...) where type is 's' for space, 'c' for
                    # CJK word, or 'w' for non-CJK word
-            while ($pt =~ /($Text::WideChar::Util::re_cjk+)|(\S+)|(\s+)/gox) {
-                if ($1) {
+            while ($pt =~ /$_re1/g) {
+                if ($is_mb && $1) {
                     push @s, $1, 'c';
                 } elsif ($3) {
                     push @s, $3, 's';
                 } else {
-                    my $pt2 = $2;
-                    while ($pt2 =~ /($Text::WideChar::Util::re_cjk_class+)|
-                                    ($Text::WideChar::Util::re_cjk_negclass+)/gox) {
-                        if ($1) {
-                            push @s, $1, 'c';
-                        } else {
-                            push @s, $2, 'w';
+                    if ($is_mb) {
+                        my $pt2 = $2;
+                        while ($pt2 =~ /$_re2/g) {
+                            if ($1) {
+                                push @s, $1, 'c';
+                            } else {
+                                push @s, $2, 'w';
+                            }
                         }
+                    } else {
+                        push @s, $2, 'w';
                     }
                 }
             }
@@ -532,8 +539,8 @@ sub _ta_trunc {
     if ($w <= $width) {
         return $return_extra ? [$text, $w, length($text), ''] : $text;
     }
-    my @p = ta_split_codes($text);
-    my @res;
+    my @p = ta_split_codes_single($text);
+    my $res = '';
     my $append = 1; # whether we should add more text
     my $code4rest = '';
     my $rest = '';
@@ -546,7 +553,7 @@ sub _ta_trunc {
             my $tw = $is_mb ? Text::WideChar::Util::mbswidth($t) : length($t);
             #say "D: tw=$tw";
             if ($w+$tw <= $width) {
-                push @res, $t;
+                $res .= $t;
                 $w += $tw;
                 $c += length($t);
                 $append = 0 if $w == $width;
@@ -556,7 +563,7 @@ sub _ta_trunc {
                     Text::WideChar::Util::mbtrunc($t, $width-$w, 1) :
                       [substr($t, 0, $width-$w), $width-$w, $width-$w];
                 #use Data::Dump; dd $tres;
-                push @res, $tres->[0];
+                $res .= $tres->[0];
                 $w += $tres->[1];
                 $c += $tres->[2];
                 $rest = substr($t, $tres->[2]);
@@ -567,20 +574,41 @@ sub _ta_trunc {
             $rest .= $t;
         }
         if (defined $ansi) {
-            push @res, $ansi;
-            $c += length($ansi) if $append;
-            $code4rest .= $ansi if $append;
-            $rest .= $ansi unless $append;
+            if ($append) {
+                if ($ansi eq "\e[0m") {
+                    #say "D:found color reset, resetting code4rest";
+                    $c = length($ansi);
+                    $code4rest = $ansi;
+                } else {
+                    $c += length($ansi);
+                    $code4rest .= $ansi;
+                }
+                $res .= $ansi;
+            } else {
+                $res .= $ansi;
+                $rest .= $ansi;
+            }
         }
     }
 
+    # ta_trunc/ta_mbtrunc currently adds unpruned color codes at the end of
+    # truncated string. pruned meaning strings of color codes right before reset
+    # code is removed, e.g. \e[1m\e[30m...\e[0m becomes \e[0m. you might want to
+    # prune the result of trunc using _ta_prune_codes.
+
     if ($return_extra) {
-        return [join("", @res), $w, $c, $code4rest . $rest];
+        return [$res, $w, $c, $code4rest . $rest];
     } else {
-        return join("", @res);
+        return $res;
     }
 }
 
+sub _ta_prune_codes {
+    my $text = shift;
+    $text =~ s/($re_mult)\e\[0m/\e\[0m/g;
+    $text;
+}
+
 sub ta_trunc {
     _ta_trunc(0, @_);
 }
@@ -776,9 +804,9 @@ sub _ta_substr {
 
     if (@_) {
         # left + replacement + right
-        return $res1->[0] . $_[0] . $res2->[3];
+        return _ta_prune_codes($res1->[0] . $_[0] . $res2->[3]);
     } else {
-        return $res2->[0];
+        return _ta_prune_codes($res2->[0]);
     }
 }
 
@@ -806,7 +834,7 @@ Text::ANSI::BaseUtil - Base for Text::ANSI::{Util,NonWideUtil,WideUtil}
 
 =head1 VERSION
 
-This document describes version 0.18 of Text::ANSI::BaseUtil (from Perl distribution Text-ANSI-Util), released on 2015-08-12.
+This document describes version 0.19 of Text::ANSI::BaseUtil (from Perl distribution Text-ANSI-Util), released on 2015-08-13.
 
 =for Pod::Coverage .+
 
