@@ -1,7 +1,7 @@
 package Text::ANSI::NonWideUtil;
 
-our $DATE = '2015-08-12'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-08-13'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -32,7 +32,7 @@ our $re = $Text::ANSI::BaseUtil::re;
 *{$_} = \&{"Text::ANSI::BaseUtil::$_"} for @EXPORT_OK;
 
 1;
-# ABSTRACT: Routines for text containing ANSI escape codes (non-wide functions only)
+# ABSTRACT: Routines for text containing ANSI color codes (non-wide functions only)
 
 __END__
 
@@ -42,21 +42,21 @@ __END__
 
 =head1 NAME
 
-Text::ANSI::NonWideUtil - Routines for text containing ANSI escape codes (non-wide functions only)
+Text::ANSI::NonWideUtil - Routines for text containing ANSI color codes (non-wide functions only)
 
 =head1 VERSION
 
-This document describes version 0.18 of Text::ANSI::NonWideUtil (from Perl distribution Text-ANSI-Util), released on 2015-08-12.
+This document describes version 0.19 of Text::ANSI::NonWideUtil (from Perl distribution Text-ANSI-Util), released on 2015-08-13.
 
 =head1 FUNCTIONS
 
 =head2 ta_detect($text) => BOOL
 
-Return true if C<$text> contains ANSI escape codes, false otherwise.
+Return true if C<$text> contains ANSI color codes, false otherwise.
 
 =head2 ta_length($text) => INT
 
-Count the number of characters in $text, while ignoring ANSI escape codes.
+Count the number of characters in $text, while ignoring ANSI color codes.
 Equivalent to C<< length(ta_strip($text)) >>. See also: ta_mbswidth().
 
 =head2 ta_length_height($text) => [INT, INT]
@@ -66,7 +66,7 @@ ta_length_height("foobar\nb\n") >> gives [6, 3].
 
 =head2 ta_strip($text) => STR
 
-Strip ANSI escape codes from C<$text>, returning the stripped text.
+Strip ANSI color codes from C<$text>, returning the stripped text.
 
 =head2 ta_extract_codes($text) => STR
 
@@ -74,8 +74,8 @@ This is the opposite of C<ta_strip()>, return only the ANSI codes in C<$text>.
 
 =head2 ta_split_codes($text) => LIST
 
-Split C<$text> to a list containing alternating ANSI escape codes and text. ANSI
-escape codes are always on the second element, fourth, and so on. Example:
+Split C<$text> to a list containing alternating ANSI color codes and text. ANSI
+color codes are always on the second element, fourth, and so on. Example:
 
  ta_split_codes("");              # => ()
  ta_split_codes("a");             # => ("a")
@@ -94,13 +94,13 @@ so you can do something like:
 
 =head2 ta_split_codes_single($text) => LIST
 
-Like C<ta_split_codes()> but each ANSI escape code is split separately, instead
+Like C<ta_split_codes()> but each ANSI color code is split separately, instead
 of grouped together. This routine is currently used internally e.g. for
 C<ta_mbwrap()> and C<ta_highlight()> to trace color reset/replay codes.
 
 =head2 ta_wrap($text, $width, \%opts) => STR
 
-Like L<Text::WideChar::Util>'s wrap() except handles ANSI escape codes. Perform
+Like L<Text::WideChar::Util>'s wrap() except handles ANSI color codes. Perform
 color reset at the end of each line and a color replay at the start of
 subsequent line so the text is safe for combining in a multicolumn/tabular
 layout.
@@ -190,7 +190,7 @@ Does *not* handle multiline text; you can split text by C</\r?\n/> yourself.
 
 =head2 ta_trunc($text, $width) => STR
 
-Truncate C<$text> to C<$width> columns while still including all the ANSI escape
+Truncate C<$text> to C<$width> columns while still including all the ANSI color
 codes. This ensures that truncated text still reset colors, etc.
 
 Does *not* handle multiline text; you can split text by C</\r?\n/> yourself.
